.. index::
   single: Function reference; Tools

Tools
=====

Data analysis
-------------

.. autofunction:: calorine.tools.analyze_data
.. autofunction:: calorine.tools.get_autocorrelation_function
.. autofunction:: calorine.tools.get_correlation_length
.. autofunction:: calorine.tools.get_error_estimate

Property calculation
--------------------
.. autofunction:: calorine.tools.get_elastic_stiffness_tensor
.. autofunction:: calorine.tools.get_force_constants
.. autofunction:: calorine.tools.get_rtc_from_hac

Structure manipulation
----------------------
.. autofunction:: calorine.tools.relax_structure

Symmetry analysis
-----------------

.. autofunction:: calorine.tools.get_primitive_structure
.. autofunction:: calorine.tools.get_spacegroup
.. autofunction:: calorine.tools.get_wyckoff_sites
